@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(check_angle check_array check_array_object
 	check_number check_number_of_items check_regexp check_required
 	check_string_begin check_strings);
 
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 sub check_angle {
 	my ($self, $key) = @_;
@@ -59,9 +59,10 @@ sub check_array_object {
 	check_array($self, $key);
 
 	foreach my $obj (@{$self->{$key}}) {
-		if (! $obj->isa($class)) {
-			err $class_name." isn't '".$class."' object.";
-		}
+		_check_object($obj, $class,
+			'%s isn\'t \'%s\' object.',
+			[$class_name, $class],
+		);
 	}
 
 	return;
@@ -115,26 +116,10 @@ sub check_isa {
 	my ($self, $key, $class) = @_;
 
 	_check_key($self, $key) && return;
-
-	if (! blessed($self->{$key})) {
-		err "Parameter '$key' must be a '$class' object.",
-
-			# Only, if value is scalar.
-			(ref $self->{$key} eq '') ? (
-				'Value', $self->{$key},
-			) : (),
-
-			# Only if value is reference.
-			(ref $self->{$key} ne '') ? (
-				'Reference', (ref $self->{$key}),
-			) : (),
-	}
-
-	if (! $self->{$key}->isa($class)) {
-		err "Parameter '$key' must be a '$class' object.",
-			'Reference', (ref $self->{$key}),
-		;
-	}
+	_check_object($self->{$key}, $class,
+		'Parameter \'%s\' must be a \'%s\' object.',
+		[$key, $class],
+	);
 
 	return;
 }
@@ -261,6 +246,34 @@ sub _check_key {
 	return 0;
 }
 
+sub _check_object {
+	my ($value, $class, $message, $message_params_ar) = @_;
+
+	if (! blessed($value)) {
+		my $err_message = sprintf $message, @{$message_params_ar};
+		err $err_message,
+
+			# Only, if value is scalar.
+			(ref $value eq '') ? (
+				'Value', $value,
+			) : (),
+
+			# Only if value is reference.
+			(ref $value ne '') ? (
+				'Reference', (ref $value),
+			) : (),
+	}
+
+	if (! $value->isa($class)) {
+		my $err_message = sprintf $message, @{$message_params_ar};
+		err $err_message,
+			'Reference', (ref $value),
+		;
+	}
+
+	return;
+}
+
 1;
 
 __END__
@@ -467,6 +480,8 @@ Returns undef.
                  Value: %s
                  Reference: %s
          %s isn't '%s' object.
+                 Value: %s
+                 Reference: %s
 
  check_array_required():
          Parameter '%s' is required.
@@ -1197,6 +1212,10 @@ Micro Objects. Mo is less.
 
 Mo language utilities.
 
+=item L<Mo::utils::CSS>
+
+Mo CSS utilities.
+
 =item L<Wikibase::Datatype::Utils>
 
 Wikibase datatype utilities.
@@ -1215,12 +1234,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2020-2023 Michal Josef Špaček
+© 2020-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.20
+0.21
 
 =cut
